@@ -3,317 +3,357 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="20"/>
+        <location filename="ui_mainwindow.h" line="392"/>
         <source>Boot Repair</source>
-        <translation type="unfinished"/>
+        <translation>Rendszerbetöltő javító</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="39"/>
+        <location filename="ui_mainwindow.h" line="393"/>
         <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"/>
+        <translation>A Rendszerbetöltő Javító egy segédprogram, amely a GRUB rendszerbetöltő újratelepítésére használható az ESP (EFI rendszer partíció), MBR (Master Boot Record) vagy root partícióra. Lehetőséget biztosít a GRUB konfigurációs fájl rekonstruálására, valamint az MBR vagy PBR (root) biztonsági mentésére és visszaállítására.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="58"/>
+        <location filename="ui_mainwindow.h" line="394"/>
         <source>What would you like to do?</source>
-        <translation type="unfinished"/>
+        <translation>Mit szeretne tenni?</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="79"/>
+        <location filename="ui_mainwindow.h" line="395"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
-        <translation type="unfinished"/>
+        <translation>MBR vagy PBR mentése (csak régi indítók)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="86"/>
+        <location filename="ui_mainwindow.h" line="396"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation type="unfinished"/>
+        <translation>GRUB rendszerbetöltő újratelepítése az ESP, MBR vagy PBR (root) helyre</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="96"/>
+        <location filename="ui_mainwindow.h" line="397"/>
         <source>Repair GRUB configuration file</source>
-        <translation type="unfinished"/>
+        <translation>GRUB beállítási fájl javítása</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="103"/>
+        <location filename="ui_mainwindow.h" line="398"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
-        <translation type="unfinished"/>
+        <translation>MBR vagy PBR visszaállítása mentésből (csak régi indítók)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="136"/>
-        <location filename="mainwindow.cpp" line="485"/>
+        <location filename="mainwindow.cpp" line="483"/>
+        <location filename="ui_mainwindow.h" line="399"/>
         <source>Select Boot Method</source>
-        <translation type="unfinished"/>
+        <translation>Válassza ki az indítási módot</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="154"/>
+        <location filename="ui_mainwindow.h" line="401"/>
         <source>Master Boot Record</source>
-        <translation type="unfinished"/>
+        <translation>Master Boot Record</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="157"/>
+        <location filename="ui_mainwindow.h" line="403"/>
         <source>MBR</source>
         <translation>MBR</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="160"/>
         <location filename="mainwindow.ui" line="430"/>
+        <location filename="ui_mainwindow.h" line="405"/>
+        <location filename="ui_mainwindow.h" line="426"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="182"/>
+        <location filename="ui_mainwindow.h" line="408"/>
         <source>Root (Partition Boot Record)</source>
-        <translation type="unfinished"/>
+        <translation>Root (Partition Boot Record)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="185"/>
-        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="mainwindow.cpp" line="486"/>
+        <location filename="ui_mainwindow.h" line="410"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="236"/>
-        <location filename="mainwindow.cpp" line="487"/>
+        <location filename="mainwindow.cpp" line="485"/>
+        <location filename="ui_mainwindow.h" line="411"/>
         <source>Install on:</source>
         <translation>Telepítés ezen:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="255"/>
-        <location filename="mainwindow.cpp" line="486"/>
+        <location filename="mainwindow.cpp" line="484"/>
+        <location filename="ui_mainwindow.h" line="412"/>
         <source>Location:</source>
-        <translation type="unfinished"/>
+        <translation>Hely:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="277"/>
-        <location filename="mainwindow.cpp" line="496"/>
+        <location filename="mainwindow.cpp" line="494"/>
+        <location filename="ui_mainwindow.h" line="416"/>
         <source>Select root location:</source>
-        <translation type="unfinished"/>
+        <translation>Válassza ki a root partíciót:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="290"/>
+        <location filename="ui_mainwindow.h" line="418"/>
         <source>EFI System Partition</source>
-        <translation type="unfinished"/>
+        <translation>EFI rendszer partíció</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="293"/>
+        <location filename="ui_mainwindow.h" line="420"/>
         <source>ESP</source>
-        <translation type="unfinished"/>
+        <translation>ESP</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="420"/>
+        <location filename="ui_mainwindow.h" line="422"/>
         <source>About this application</source>
         <translation>Az alkalmazásról</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="423"/>
+        <location filename="ui_mainwindow.h" line="424"/>
         <source>About...</source>
         <translation>Névjegy</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="472"/>
+        <location filename="ui_mainwindow.h" line="429"/>
         <source>Display help </source>
         <translation>Súgó megjelenítése</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="475"/>
+        <location filename="ui_mainwindow.h" line="431"/>
         <source>Help</source>
         <translation>Súgó</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="482"/>
+        <location filename="ui_mainwindow.h" line="433"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="523"/>
+        <location filename="ui_mainwindow.h" line="437"/>
         <source>Cancel any changes then quit</source>
-        <translation>Változtatások visszavonása és kilépés</translation>
+        <translation>Változtatások elvetése és kilépés</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="526"/>
+        <location filename="ui_mainwindow.h" line="439"/>
         <source>Cancel</source>
         <translation>Mégsem</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="533"/>
+        <location filename="ui_mainwindow.h" line="441"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="552"/>
+        <location filename="ui_mainwindow.h" line="444"/>
         <source>Apply any changes</source>
-        <translation type="unfinished"/>
+        <translation>Változtatások alkalmazása</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="555"/>
-        <location filename="mainwindow.cpp" line="70"/>
+        <location filename="mainwindow.cpp" line="71"/>
+        <location filename="ui_mainwindow.h" line="446"/>
         <source>Apply</source>
-        <translation>Alkamaz</translation>
+        <translation>Alkalmazás</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="86"/>
+        <location filename="mainwindow.cpp" line="87"/>
         <source>GRUB is being installed on %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>GRUB a %1 eszközre kerül.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="118"/>
-        <location filename="mainwindow.cpp" line="203"/>
-        <location filename="mainwindow.cpp" line="312"/>
-        <location filename="mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="110"/>
+        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.cpp" line="192"/>
+        <location filename="mainwindow.cpp" line="216"/>
+        <location filename="mainwindow.cpp" line="322"/>
+        <location filename="mainwindow.cpp" line="396"/>
         <location filename="mainwindow.cpp" line="419"/>
-        <location filename="mainwindow.cpp" line="527"/>
-        <location filename="mainwindow.cpp" line="534"/>
-        <location filename="mainwindow.cpp" line="597"/>
+        <location filename="mainwindow.cpp" line="525"/>
+        <location filename="mainwindow.cpp" line="532"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="119"/>
-        <location filename="mainwindow.cpp" line="204"/>
+        <location filename="mainwindow.cpp" line="110"/>
+        <location filename="mainwindow.cpp" line="192"/>
+        <source>Could not create a temporary folder</source>
+        <translation>Ideiglenes mappa létrehozása nem sikerült</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.cpp" line="216"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
-        <translation type="unfinished"/>
+        <translation>Nem sikerült a chroot környezet kialakítása.
+Ellenőrizze a kiválasztott helyet.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="179"/>
+        <location filename="mainwindow.cpp" line="189"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
-        <translation type="unfinished"/>
+        <translation>A GRUB konfigurációs fájl (grub.cfg) rekonstruálása.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="222"/>
+        <location filename="mainwindow.cpp" line="233"/>
         <source>Backing up MBR or PBR from %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>MBR vagy PBR mentése a %1 eszközről.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="287"/>
+        <location filename="mainwindow.cpp" line="297"/>
         <source>Warning</source>
         <translation>Figyelmeztetés</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>You are going to write the content of </source>
-        <translation type="unfinished"/>
+        <translation>Ki fogja írni a tartalmát ennek:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source> to </source>
-        <translation type="unfinished"/>
+        <translation>ide:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>
 
 Are you sure?</source>
-        <translation type="unfinished"/>
+        <translation>
+
+Biztos benne?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="303"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>MBR/PBR visszaállítása mentésből a %1 eszközre.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="313"/>
+        <location filename="mainwindow.cpp" line="322"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
-        <translation type="unfinished"/>
+        <translation>Nem található EFI rendszer partíció (ESP) egyik rendszer lemezen sem. Hozzon létre egy ESP-t és próbálja újra.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="348"/>
+        <location filename="mainwindow.cpp" line="353"/>
         <source>Select %1 location:</source>
-        <translation type="unfinished"/>
+        <translation>%1 helyének kiválasztása:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="372"/>
+        <location filename="mainwindow.cpp" line="375"/>
         <source>Back</source>
         <translation>Vissza</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="388"/>
+        <location filename="mainwindow.cpp" line="391"/>
         <source>Success</source>
-        <translation type="unfinished"/>
+        <translation>Sikeres</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="389"/>
+        <location filename="mainwindow.cpp" line="392"/>
         <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
-        <translation type="unfinished"/>
+        <translation>A feldolgozás sikeresen befejeződött.&lt;p&gt;&lt;b&gt;Kilép a rendszerbetöltő javítóból?&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="395"/>
+        <location filename="mainwindow.cpp" line="396"/>
         <source>Process finished. Errors have occurred.</source>
-        <translation type="unfinished"/>
+        <translation>A feldolgozás befejeződött. Hibák történtek.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="412"/>
+        <location filename="mainwindow.cpp" line="413"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
-        <translation type="unfinished"/>
+        <translation>Adja meg a jelszót a %1 titkosított partíció feloldásához:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="420"/>
+        <location filename="mainwindow.cpp" line="419"/>
         <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="unfinished"/>
+        <translation>Nem sikerült a %1 LUKS konténer megnyitása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="495"/>
+        <location filename="mainwindow.cpp" line="493"/>
         <source>Select GRUB location</source>
-        <translation type="unfinished"/>
+        <translation>Válassza ki a GRUB helyét</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="507"/>
+        <location filename="mainwindow.cpp" line="505"/>
         <source>Select Item to Back Up</source>
-        <translation type="unfinished"/>
+        <translation>Válassza ki a menteni kívánt elemet</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="514"/>
+        <location filename="mainwindow.cpp" line="512"/>
         <source>Select Item to Restore</source>
-        <translation type="unfinished"/>
+        <translation>Válassza ki a visszaállítani kívánt elemet</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="523"/>
+        <source>Select backup file name</source>
+        <translation>Adja meg a mentés fájlnevét</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="525"/>
-        <source>Select backup file name</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="527"/>
-        <location filename="mainwindow.cpp" line="534"/>
-        <source>No file was selected.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
         <location filename="mainwindow.cpp" line="532"/>
+        <source>No file was selected.</source>
+        <translation>Nincs fájl kiválasztva.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="530"/>
         <source>Select MBR or PBR backup file</source>
-        <translation type="unfinished"/>
+        <translation>Válasszon ki egy MBR vagy PBR mentés fájlt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
+        <location filename="mainwindow.cpp" line="550"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>%1 névjegye</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="553"/>
+        <location filename="mainwindow.cpp" line="551"/>
         <source>Version: </source>
         <translation>Verzió:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="554"/>
+        <location filename="mainwindow.cpp" line="552"/>
         <source>Simple boot repair program for antiX Linux</source>
-        <translation type="unfinished"/>
+        <translation>Egyszerű rendszerbetöltő javító antiX Linuxhoz</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="556"/>
+        <location filename="mainwindow.cpp" line="554"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="557"/>
+        <location filename="mainwindow.cpp" line="555"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 licenc</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="568"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Súgó</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="598"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>Sorry, could not mount %1 partition</source>
-        <translation type="unfinished"/>
+        <translation>Nem sikerült a %1 partíció csatolása</translation>
     </message>
 </context>
 <context>
@@ -321,13 +361,13 @@ Are you sure?</source>
     <message>
         <location filename="about.cpp" line="32"/>
         <source>License</source>
-        <translation>Liszensz</translation>
+        <translation>Licenc</translation>
     </message>
     <message>
         <location filename="about.cpp" line="33"/>
         <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation>Változásbejegyzés</translation>
+        <translation>Változások listája</translation>
     </message>
     <message>
         <location filename="about.cpp" line="34"/>
@@ -337,12 +377,20 @@ Are you sure?</source>
     <message>
         <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation>&amp;Bezár</translation>
+        <translation>&amp;Bezárás</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="main.cpp" line="57"/>
+        <source>Error</source>
+        <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="64"/>
-        <source>You must run this program as root.</source>
-        <translation>Root felhasználóként kell futtatnia ezt a programot!</translation>
+        <location filename="main.cpp" line="58"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be normál felhasználóként a program használatához.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
