@@ -132,7 +132,7 @@
         <location filename="mainwindow.ui" line="472"/>
         <location filename="ui_mainwindow.h" line="429"/>
         <source>Display help </source>
-        <translation>Exibir a ajuda</translation>
+        <translation>Exibir ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="475"/>
